/*
    CREATION OF A CENSUS FILE FOR ANALYSIS
	MARTIN SPIELAUER, 2016
	CENSUS 2013 12% SAMPLE

	VARIABLES:
	
	- M_ID		  	Record ID
	- M_WEIGHT		Weight
	- M_AGE			Age
	- M_MALE		Sex
	- M_POB			Province of birth
	- M_POR			Province of residence (including abroad for recent emigrants)
	- M_PPROV		Province 12 months ago
	- M_EDUC		Education (no - enter - finish primary)
	- M_AGEMAR		Age at first marriage
	- M_PARITY		Number of births
	- M_BIR12		Births in past 12 months
	- M_AGEBIR		Age at most recent birth
	
	OUTPUT FILES:
	
	- m_census_residents.dta
	- m_census_emigrants.dta
	- m_census_all_incl_emigrants.dta
	- m_census_immigrants.dta
*/

/* ************************ */
/* DATA RESIDENT POPULATION */
/* ************************ */

clear all
#delimit; 
use "Census\raw_census_sample_residents.dta";

/* VARIABLES */

/* RECORD ID */
gen double M_ID = ID1*1000000000000 + ID2*100000000000 + ID3*1000000000 + ID4*1000000 + nummen*1000 + Q01;
	format M_ID %18.0g; 

/* WEIGHT weight 12% sample (total = 3,537,368) */
gen M_WEIGHT = pondfact*8.39008117;

/* AGE */
gen M_AGE = age + runiform();

/* SEX */
gen M_MALE = 0; replace M_MALE = 1 if Q04==1;

/* PROVINCE OF BIRTH */
gen M_POB = Q13-1;
	replace M_POB = 13 if Q13 > 13;
	label define M_PROV 
		0 "Hodh_Charghy"
		1 "Hodh_Gharby"
		2 "Assaba"
		3 "Gorgol"
		4 "Brakna"
		5 "Trarza"
		6 "Adrar"
		7 "Dakhlett_Nouadibou"
		8 "Tagant"
		9 "Guidimagha"
		10 "Tirs_Ezemour"
		11 "Inchiri"
		12 "Nouakchott"
		13 "Abroad";
	label values M_POB M_PROV;	
	
/* PROVINCE OF RESIDENCE */
gen M_POR = ID1-1;
	label values M_POR M_PROV;	

/* PROVINCE 12 MONTHS AGO */
gen M_PPROV = M_POR;
	replace M_PPROV = 13 		if Q14==2 & Q15 > 13 & Q15!=.;				// immigrant
	replace M_PPROV = 13 		if age==0 & Q13 > 13 & Q13!=.;				// immigrant age 0
	replace M_PPROV = Q15-1 	if Q14==2 & Q15<=13 & age>0 & Q15!=ID1;		// move and age > 0
	replace M_PPROV = Q13-1		if ID1!=Q13 & Q13<=13 & age==0;				// move and age = 0 
	label values M_PPROV M_PROV;	
	
/* EDUCATION */	
gen M_EDUC = 0;																// never entered school		
	replace M_EDUC = 1 if niv_inst==3 & Q20==0; 							// primary dropout
	replace M_EDUC = 2 if niv_inst>=3 & Q20>=10 & Q20<26;					// primary and above	
	label define M_EDUC 
		0 "non" 		
		1 "some_primary" 
		2 "primary_plus";
 	label values M_EDUC M_EDUC;

/* AGE AT FIRST MARRIAGE 	
   Missing values ~3% are distributed randomly to ages 14-25 if currently > 25
   and between 14 and current age if between 14 and 25.
   For younger, the event is scheduled in past year 
*/
gen M_AGEMAR = .;
	replace M_AGEMAR = Q28 + runiform() if Q28 < 98;
	replace M_AGEMAR = M_AGE - runiform() if M_AGEMAR > M_AGE & Q28 < 98;
	replace M_AGEMAR = 14 + 11 * runiform() if Q28 == 98 & M_AGE > 25;
	replace M_AGEMAR = 14 + (M_AGE - 14) * runiform() if Q28 == 98 & M_AGE <= 25 & M_AGE >= 14;
	replace M_AGEMAR = M_AGE - runiform() if Q28 == 98 & M_AGEMAR == .;

/* PARITY */
gen M_PARITY = 0;
	replace M_PARITY = neviv_tot if neviv_tot > 0 & neviv_tot != .;
	replace M_PARITY = 15 if M_PARITY > 15;
	
/* BIRTHS IN PAST 12 MONTHS 
   Ad hoc corrections for unplausible numbers:
   - No birth allowed for persons 50+
   - Max allowed is 3 births
   - then 90% of 3 births set to 2
   - then 50% of 2 births changed to 1
*/
gen M_BIR12 = 0;
	replace M_BIR12 = neviv_12m if neviv_12m !=. & M_AGE < 50;
	replace M_BIR12 = 3 if M_BIR12 > 3;
	replace M_BIR12 = 2 if M_BIR12==3 & runiform()<0.9;
	replace M_BIR12 = 1 if M_BIR12==2 & runiform()<0.5;

gen M_MALI = 0;
	replace M_MALI = 1 if M_PPROV == 13 & Q15 == 22;
	
keep M_*;
save "Microdata\m_census_residents.dta", replace;

/* ************************ */
/* IMMIGRANT POPULATION     */
/* ************************ */

/* Drop residents 
   and drop 95% of immigrants from Mali (refugee immigration not expected to continue) 
*/
drop if M_PPROV != 13; drop if M_MALI == 1 & runiform() < 0.95; drop M_MALI;
save "Microdata\m_census_immigrants.dta", replace;

/* remove M_MALI variable from file of residents */
clear all; use "Microdata\m_census_residents.dta"; drop M_MALI;
save "Microdata\m_census_residents.dta", replace;

/* ************************ */
/* DATA EMIGRANT POPULATION */
/* ************************ */

clear	all;
use 	"Census\raw_census_sample_emigrants.dta";

/* KEEP EMIGRANTS 2012 ONLY*/
drop if Annededpart != 2012;

/* RECORD ID */
gen double M_ID = Wilaya*1000000000000 + Moughataa*100000000000 + Commune*1000000000 + NumroduDR*1000000 + NumroMnagesquentiel*1000 + 900+NUM;
	format M_ID %18.0g; 

/* WEIGHT */
gen M_WEIGHT = R;
	
/* AGE 
   Some missings (Ageaudpart = 98) get random age 0-60 
*/
gen M_AGE = Ageaudpart + 2 * runiform();	
	replace M_AGE = 60 * runiform() if Ageaudpart == 98;
			
/* SEX */
gen M_MALE = 0; replace M_MALE = 1 if Sexe==1;

/* PROVINCE OF RESIDENCE */
gen M_POR = 13;
	label values M_POR M_PROV;	

/* PROVINCE 12 MONTHS AGO */
gen M_PPROV = Wilaya-1;
	label values M_PPROV M_PROV;

keep M_*;
save "Microdata\m_census_emigrants.dta", replace;

/* ********************************************** */
/* MERGE DATA OF RESIDENT AND EMIGRANT POPULATION */
/* ********************************************** */

clear	all;
use 	"Microdata\m_census_residents.dta";
append 	using "Microdata\m_census_emigrants.dta";
save 	"Microdata\m_census_all_incl_emigrants.dta", replace;




