/*
BIRTHS 1-14
DATA FROM MICS MAURITANIA
MARTIN SPIELAUER, 2016

Input Data:

    - m_mics_fertility.dta

The data file contains women age 10-49 and contains the the following 
variables: (dates are months since 1900)

	- M_ID 				ID of Woman
	- M_WEIGHT 			Weight	
	- M_BIRTH 			Date of birth
	- M_B01 to M_B14 	Dates of births 1-14 
	- M_EDUC 			Primary education: 0 non, 1 Primary dropout, 2 Primary graduate+ 
	- M_MAR 			Date of first marriage
	- M_INTERV			Date of interview	
*/

/*
-------------------------------
Wrapper function stpiece
-------------------------------

the following adds the wrapper function stpiece which can be used to make code more efficient;
without this function, time splits of the baseline have to be done manually;
the fuction can be added to Stata, download at: http://fmwww.bc.edu/repec/bocode/s/stpiece.ado;
it was developed by Jesper B. Sorensen Nov. 20 1999;
*/

clear all

program define stpiece
    version 6.0
    syntax [varlist(default=none numeric)] [if] [in] , [tp(numlist >=0) tv(varlist) PREsplit(integer -1) noPREserve *]
    if "`preserv'"=="" {
        preserve
    }
    if "`presplit'" == "-1" {
        if "`tp'"=="" {
            di in red "You must either declare data to be presplit or use tp()"
            exit 198
        }
        di in gr "Invoking stsplit..."
        qui stsplit tp, at(`tp') 
        di in gr "Creating time pieces..."
        qui tab tp, gen(tp)
        local i = _result(2)
        drop tp
    }
    else {
        local i = "`presplit'"
    }
    if "`tv'" ~= "" {
        di in gr "Creating interaction effects..."
        tokenize `tv'
        while "`1'" ~= "" {
            local stub = substr("`1'",1,4)
            local j=0
            while "`j'" < "`i'" {
                local j = `j'+1
                local x = "tp`stub'`j'"
                qui gen  `x'=`1'*tp`j'
            }
         mac shift
        }
    }

    streg tp* `varlist' `if' `in' , nocons d(e) `options'

end


/* ********************************************************* */
/* ********************************************************* */
/* **                    BIRTH 01                         ** */
/* ********************************************************* */
/* ********************************************************* */

/*******************************************/
/* Settings and input file                 */
/*******************************************/

#delimit;
clear;
capture log close;
set more off;
set linesize 255;
log using "13_HigherOrderBirthsMics_cmap.smcl", replace smcl;
use m_mics_fertility.dta;

/*******************************************/
/* New Variables                           */
/*******************************************/

/* Record number */
generate m_recno = _n;

/* The studied event */

generate m_birthevent = 0;
replace  m_birthevent = 1 if M_B01 != .;	

/* Observation time */

generate m_duration = ( M_INTERV - M_BIRTH ) / 12.0 - 10;
replace  m_duration = ( M_B01 - M_BIRTH ) / 12.0 - 10 if m_birthevent==1;

/* Censor at age 50 and drop cases with birth before age 10 */

drop if m_duration < 0; 
replace m_birthevent = 0 if m_duration > 40;
replace m_duration=40 if m_duration>40;

/*******************************************/
/* EPISODE SPLITTING                       */ 
/*******************************************/

stset m_duration, failure(m_birthevent) id(m_recno);

/* splitting file in period episodes */

stsplit m_after1980, after at ( 0 10 20 ) ( time = 1980 - (1900 + M_BIRTH /12.0) - 10);
replace m_after1980=3 if m_after1980==20;
replace m_after1980=2 if m_after1980==10;
replace m_after1980=1 if m_after1980==0;
replace m_after1980=0 if m_after1980==-1;
label define m_after1980 
  0 "Before 1980" 
  1 "1980-1989" 
  2 "1990-1999"
  3 "2000+";
label values m_after1980 m_after1980 ;
char m_after1980[omit]3;

/* Splitting periods before / after union formation */

generate m_firstunion = (M_MAR - M_BIRTH) / 12.0 - 10;

stsplit m_unionduration, after at(0) (time=m_firstunion); 
replace m_unionduration=-1 if m_firstunion==.; 
replace m_unionduration = m_unionduration + 1;
char m_unionduration[omit]1;

/*******************************************/
/* ESTIMATION BIRTH 1                      */ 
/*******************************************/

xi: stpiece  i.m_after1980 i.M_EDUC i.m_unionduration, tp( 2.5, 5, 7.5, 10, 12.5, 15, 17.5, 20, 22.5, 25, 27.5, 30, 32.5, 35, 37.5 );


/* ********************************************************* */
/* ********************************************************* */
/* **                    BIRTH 02                         ** */
/* ********************************************************* */
/* ********************************************************* */

/*******************************************/
/* Settings and input file                 */
/*******************************************/

#delimit;
clear;
use m_mics_fertility.dta;
drop if M_B01 == .;

/*******************************************/
/* New Variables                           */
/*******************************************/

/* Record number */
generate m_recno = _n;

/* The studied event M_B02*/

generate m_birthevent = 0;
replace  m_birthevent = 1 if M_B02 != .;	

/* Observation time */

generate  m_duration = ( M_INTERV - M_B01 ) / 12.0;
replace   m_duration = ( M_B02 - M_B01 ) / 12.0 if m_birthevent==1;

/*******************************************/
/* EPISODE SPLITTING                       */ 
/*******************************************/

stset m_duration, failure(m_birthevent) id(m_recno);

/* splitting file in period episodes */

stsplit m_after1980, after at ( 0 10 20 ) ( time = 1980 - (1900 + M_B01 /12.0));
replace m_after1980=3 if m_after1980==20;
replace m_after1980=2 if m_after1980==10;
replace m_after1980=1 if m_after1980==0;
replace m_after1980=0 if m_after1980==-1;
label define m_after1980 
  0 "Before 1980" 
  1 "1980-1989" 
  2 "1990-1999"
  3 "2000+";
label values m_after1980 m_after1980 ;
char m_after1980[omit]3;

stsplit m_after35, after at (0,5,10) ( time =  35 + (M_BIRTH - M_B01)/12.0);
replace m_after35=-1 if m_after35==.; 
replace m_after35 = m_after35 + 1;


/*******************************************/
/* ESTIMATION BIRTH 2                      */ 
/*******************************************/

xi: stpiece  i.m_after1980 i.m_after35 i.M_EDUC , tp( 1, 3, 6, 9, 12 );



/* ********************************************************* */
/* ********************************************************* */
/* **                    BIRTH 03                         ** */
/* ********************************************************* */
/* ********************************************************* */

/*******************************************/
/* Settings and input file                 */
/*******************************************/

#delimit;
clear;
use m_mics_fertility.dta;
drop if M_B02 == .;

/*******************************************/
/* New Variables                           */
/*******************************************/

/* Record number */
generate m_recno = _n;

/* The studied event M_B03*/

generate m_birthevent = 0;
replace  m_birthevent = 1 if M_B03 != .;	

/* Observation time */

generate  m_duration = ( M_INTERV - M_B02 ) / 12.0;
replace   m_duration = ( M_B03 - M_B02 ) / 12.0 if m_birthevent==1;

/*******************************************/
/* EPISODE SPLITTING                       */ 
/*******************************************/

stset m_duration, failure(m_birthevent) id(m_recno);

/* splitting file in period episodes */

stsplit m_after1980, after at ( 0 10 20 ) ( time = 1980 - (1900 + M_B02 /12.0));
replace m_after1980=3 if m_after1980==20;
replace m_after1980=2 if m_after1980==10;
replace m_after1980=1 if m_after1980==0;
replace m_after1980=0 if m_after1980==-1;
label define m_after1980 
  0 "Before 1980" 
  1 "1980-1989" 
  2 "1990-1999"
  3 "2000+";
label values m_after1980 m_after1980 ;
char m_after1980[omit]3;

stsplit m_after35, after at (0,5,10) ( time =  35 + (M_BIRTH - M_B02)/12.0);
replace m_after35=-1 if m_after35==.; 
replace m_after35 = m_after35 + 1;


/*******************************************/
/* ESTIMATION BIRTH 3                      */ 
/*******************************************/

xi: stpiece  i.m_after1980 i.m_after35 i.M_EDUC , tp( 1, 3, 6, 9, 12 );



/* ********************************************************* */
/* ********************************************************* */
/* **                    BIRTH 04                         ** */
/* ********************************************************* */
/* ********************************************************* */


/*******************************************/
/* Settings and input file                 */
/*******************************************/

#delimit;
clear;
use m_mics_fertility.dta;
drop if M_B03 == .;

/*******************************************/
/* New Variables                           */
/*******************************************/

/* Record number */
generate m_recno = _n;

/* The studied event M_B04*/

generate m_birthevent = 0;
replace  m_birthevent = 1 if M_B04 != .;	

/* Observation time */

generate  m_duration = ( M_INTERV - M_B03 ) / 12.0;
replace   m_duration = ( M_B04 - M_B03 ) / 12.0 if m_birthevent==1;

/*******************************************/
/* EPISODE SPLITTING                       */ 
/*******************************************/

stset m_duration, failure(m_birthevent) id(m_recno);

/* splitting file in period episodes */

stsplit m_after1980, after at ( 0 10 20 ) ( time = 1980 - (1900 + M_B03 /12.0));
replace m_after1980=3 if m_after1980==20;
replace m_after1980=2 if m_after1980==10;
replace m_after1980=1 if m_after1980==0;
replace m_after1980=0 if m_after1980==-1;
label define m_after1980 
  0 "Before 1980" 
  1 "1980-1989" 
  2 "1990-1999"
  3 "2000+";
label values m_after1980 m_after1980 ;
char m_after1980[omit]3;

stsplit m_after35, after at (0,5,10) ( time =  35 + (M_BIRTH - M_B03)/12.0);
replace m_after35=-1 if m_after35==.; 
replace m_after35 = m_after35 + 1;


/*******************************************/
/* ESTIMATION BIRTH 4                      */ 
/*******************************************/

xi: stpiece  i.m_after1980 i.m_after35 i.M_EDUC , tp( 1, 3, 6, 9, 12 );



/* ********************************************************* */
/* ********************************************************* */
/* **                    BIRTH 05                         ** */
/* ********************************************************* */
/* ********************************************************* */


/*******************************************/
/* Settings and input file                 */
/*******************************************/

#delimit;
clear;
use m_mics_fertility.dta;
drop if M_B04 == .;

/*******************************************/
/* New Variables                           */
/*******************************************/

/* Record number */
generate m_recno = _n;

/* The studied event M_B05*/

generate m_birthevent = 0;
replace  m_birthevent = 1 if M_B05 != .;	

/* Observation time */

generate  m_duration = ( M_INTERV - M_B04 ) / 12.0;
replace   m_duration = ( M_B05 - M_B04 ) / 12.0 if m_birthevent==1;

/*******************************************/
/* EPISODE SPLITTING                       */ 
/*******************************************/

stset m_duration, failure(m_birthevent) id(m_recno);

/* splitting file in period episodes */

stsplit m_after1980, after at ( 0 10 20 ) ( time = 1980 - (1900 + M_B04 /12.0));
replace m_after1980=3 if m_after1980==20;
replace m_after1980=2 if m_after1980==10;
replace m_after1980=1 if m_after1980==0;
replace m_after1980=0 if m_after1980==-1;
label define m_after1980 
  0 "Before 1980" 
  1 "1980-1989" 
  2 "1990-1999"
  3 "2000+";
label values m_after1980 m_after1980 ;
char m_after1980[omit]3;

stsplit m_after35, after at (0,5,10) ( time =  35 + (M_BIRTH - M_B04)/12.0);
replace m_after35=-1 if m_after35==.; 
replace m_after35 = m_after35 + 1;


/*******************************************/
/* ESTIMATION BIRTH 5                      */ 
/*******************************************/

xi: stpiece  i.m_after1980 i.m_after35 i.M_EDUC , tp( 1, 3, 6, 9, 12 );


/* ********************************************************* */
/* ********************************************************* */
/* **                    BIRTH 06                         ** */
/* ********************************************************* */
/* ********************************************************* */


/*******************************************/
/* Settings and input file                 */
/*******************************************/

#delimit;
clear;
use m_mics_fertility.dta;
drop if M_B05 == .;

/*******************************************/
/* New Variables                           */
/*******************************************/

/* Record number */
generate m_recno = _n;

/* The studied event M_B06*/

generate m_birthevent = 0;
replace  m_birthevent = 1 if M_B06 != .;	

/* Observation time */

generate  m_duration = ( M_INTERV - M_B05 ) / 12.0;
replace   m_duration = ( M_B06 - M_B05 ) / 12.0 if m_birthevent==1;

/*******************************************/
/* EPISODE SPLITTING                       */ 
/*******************************************/

stset m_duration, failure(m_birthevent) id(m_recno);

/* splitting file in period episodes */

stsplit m_after1980, after at ( 0 10 20 ) ( time = 1980 - (1900 + M_B05 /12.0));
replace m_after1980=3 if m_after1980==20;
replace m_after1980=2 if m_after1980==10;
replace m_after1980=1 if m_after1980==0;
replace m_after1980=0 if m_after1980==-1;
label define m_after1980 
  0 "Before 1980" 
  1 "1980-1989" 
  2 "1990-1999"
  3 "2000+";
label values m_after1980 m_after1980 ;
char m_after1980[omit]3;

stsplit m_after35, after at (0,5,10) ( time =  35 + (M_BIRTH - M_B05)/12.0);
replace m_after35=-1 if m_after35==.; 
replace m_after35 = m_after35 + 1;


/*******************************************/
/* ESTIMATION  BIRTH 6                     */ 
/*******************************************/

xi: stpiece  i.m_after1980 i.m_after35 i.M_EDUC , tp( 1, 3, 6, 9, 12 );


/* ********************************************************* */
/* ********************************************************* */
/* **                    BIRTH 07                         ** */
/* ********************************************************* */
/* ********************************************************* */


/*******************************************/
/* Settings and input file                 */
/*******************************************/

#delimit;
clear;
use m_mics_fertility.dta;
drop if M_B06 == .;

/*******************************************/
/* New Variables                           */
/*******************************************/

/* Record number */
generate m_recno = _n;

/* The studied event M_B07*/

generate m_birthevent = 0;
replace  m_birthevent = 1 if M_B07 != .;	

/* Observation time */

generate  m_duration = ( M_INTERV - M_B06 ) / 12.0;
replace   m_duration = ( M_B07 - M_B06 ) / 12.0 if m_birthevent==1;

/*******************************************/
/* EPISODE SPLITTING                       */ 
/*******************************************/

stset m_duration, failure(m_birthevent) id(m_recno);

/* splitting file in period episodes */

stsplit m_after1980, after at ( 0 10 20 ) ( time = 1980 - (1900 + M_B06 /12.0));
replace m_after1980=3 if m_after1980==20;
replace m_after1980=2 if m_after1980==10;
replace m_after1980=1 if m_after1980==0;
replace m_after1980=0 if m_after1980==-1;
label define m_after1980 
  0 "Before 1980" 
  1 "1980-1989" 
  2 "1990-1999"
  3 "2000+";
label values m_after1980 m_after1980 ;
char m_after1980[omit]3;

stsplit m_after35, after at (0,5,10) ( time =  35 + (M_BIRTH - M_B06)/12.0);
replace m_after35=-1 if m_after35==.; 
replace m_after35 = m_after35 + 1;


/*******************************************/
/* ESTIMATION  BIRTH 7                     */ 
/*******************************************/

xi: stpiece  i.m_after1980 i.m_after35 i.M_EDUC , tp( 1, 3, 6, 9, 12 );



/* ********************************************************* */
/* ********************************************************* */
/* **                    BIRTH 08                         ** */
/* ********************************************************* */
/* ********************************************************* */


/*******************************************/
/* Settings and input file                 */
/*******************************************/

#delimit;
clear;
use m_mics_fertility.dta;
drop if M_B07 == .;

/*******************************************/
/* New Variables                           */
/*******************************************/

/* Record number */
generate m_recno = _n;

/* The studied event M_B08*/

generate m_birthevent = 0;
replace  m_birthevent = 1 if M_B08 != .;	

/* Observation time */

generate  m_duration = ( M_INTERV - M_B07 ) / 12.0;
replace   m_duration = ( M_B08 - M_B07 ) / 12.0 if m_birthevent==1;

/*******************************************/
/* EPISODE SPLITTING                       */ 
/*******************************************/

stset m_duration, failure(m_birthevent) id(m_recno);

/* splitting file in period episodes */

stsplit m_after1980, after at ( 0 10 20 ) ( time = 1980 - (1900 + M_B07 /12.0));
replace m_after1980=3 if m_after1980==20;
replace m_after1980=2 if m_after1980==10;
replace m_after1980=1 if m_after1980==0;
replace m_after1980=0 if m_after1980==-1;
label define m_after1980 
  0 "Before 1980" 
  1 "1980-1989" 
  2 "1990-1999"
  3 "2000+";
label values m_after1980 m_after1980 ;
char m_after1980[omit]3;

stsplit m_after35, after at (0,5,10) ( time =  35 + (M_BIRTH - M_B07)/12.0);
replace m_after35=-1 if m_after35==.; 
replace m_after35 = m_after35 + 1;


/*******************************************/
/* ESTIMATION  BIRTH 8                     */ 
/*******************************************/

xi: stpiece  i.m_after1980 i.m_after35 i.M_EDUC , tp( 1, 3, 6, 9, 12 );



/* ********************************************************* */
/* ********************************************************* */
/* **                    BIRTH 09                         ** */
/* ********************************************************* */
/* ********************************************************* */


/*******************************************/
/* Settings and input file                 */
/*******************************************/

#delimit;
clear;
use m_mics_fertility.dta;
drop if M_B08 == .;

/*******************************************/
/* New Variables                           */
/*******************************************/

/* Record number */
generate m_recno = _n;

/* The studied event M_B09*/

generate m_birthevent = 0;
replace  m_birthevent = 1 if M_B09 != .;	

/* Observation time */

generate  m_duration = ( M_INTERV - M_B08 ) / 12.0;
replace   m_duration = ( M_B09 - M_B08 ) / 12.0 if m_birthevent==1;

/*******************************************/
/* EPISODE SPLITTING                       */ 
/*******************************************/

stset m_duration, failure(m_birthevent) id(m_recno);

/* splitting file in period episodes */

stsplit m_after1980, after at ( 0 10 20 ) ( time = 1980 - (1900 + M_B08 /12.0));
replace m_after1980=3 if m_after1980==20;
replace m_after1980=2 if m_after1980==10;
replace m_after1980=1 if m_after1980==0;
replace m_after1980=0 if m_after1980==-1;
label define m_after1980 
  0 "Before 1980" 
  1 "1980-1989" 
  2 "1990-1999"
  3 "2000+";
label values m_after1980 m_after1980 ;
char m_after1980[omit]3;

stsplit m_after35, after at (0,5,10) ( time =  35 + (M_BIRTH - M_B08)/12.0);
replace m_after35=-1 if m_after35==.; 
replace m_after35 = m_after35 + 1;


/*******************************************/
/* ESTIMATION  BIRTH 9                     */ 
/*******************************************/

xi: stpiece  i.m_after1980 i.m_after35 i.M_EDUC , tp( 1, 3, 6, 9, 12 );


/* ********************************************************* */
/* ********************************************************* */
/* **                    BIRTH 10                         ** */
/* ********************************************************* */
/* ********************************************************* */


/*******************************************/
/* Settings and input file                 */
/*******************************************/

#delimit;
clear;
use m_mics_fertility.dta;
drop if M_B09 == .;

/*******************************************/
/* New Variables                           */
/*******************************************/

/* Record number */
generate m_recno = _n;

/* The studied event M_B10*/

generate m_birthevent = 0;
replace  m_birthevent = 1 if M_B10 != .;	

/* Observation time */

generate  m_duration = ( M_INTERV - M_B09 ) / 12.0;
replace   m_duration = ( M_B10 - M_B09 ) / 12.0 if m_birthevent==1;

/*******************************************/
/* EPISODE SPLITTING                       */ 
/*******************************************/

stset m_duration, failure(m_birthevent) id(m_recno);

/* splitting file in period episodes */

stsplit m_after1980, after at ( 0 10 20 ) ( time = 1980 - (1900 + M_B09 /12.0));
replace m_after1980=3 if m_after1980==20;
replace m_after1980=2 if m_after1980==10;
replace m_after1980=1 if m_after1980==0;
replace m_after1980=0 if m_after1980==-1;
label define m_after1980 
  0 "Before 1980" 
  1 "1980-1989" 
  2 "1990-1999"
  3 "2000+";
label values m_after1980 m_after1980 ;
char m_after1980[omit]3;

stsplit m_after35, after at (0,5,10) ( time =  35 + (M_BIRTH - M_B09)/12.0);
replace m_after35=-1 if m_after35==.; 
replace m_after35 = m_after35 + 1;


/*******************************************/
/* ESTIMATION  BIRTH 10                    */ 
/*******************************************/

xi: stpiece  i.m_after1980 i.m_after35 i.M_EDUC , tp( 1, 3, 6, 9, 12 );



/* ********************************************************* */
/* ********************************************************* */
/* **                    BIRTH 11                         ** */
/* ********************************************************* */
/* ********************************************************* */


/*******************************************/
/* Settings and input file                 */
/*******************************************/

#delimit;
clear;
use m_mics_fertility.dta;
drop if M_B10 == .;

/*******************************************/
/* New Variables                           */
/*******************************************/

/* Record number */
generate m_recno = _n;

/* The studied event M_B11*/

generate m_birthevent = 0;
replace  m_birthevent = 1 if M_B11 != .;	

/* Observation time */

generate  m_duration = ( M_INTERV - M_B10 ) / 12.0;
replace   m_duration = ( M_B11 - M_B10 ) / 12.0 if m_birthevent==1;

/*******************************************/
/* EPISODE SPLITTING                       */ 
/*******************************************/

stset m_duration, failure(m_birthevent) id(m_recno);

/* splitting file in period episodes */

stsplit m_after1980, after at ( 0 10 20 ) ( time = 1980 - (1900 + M_B10 /12.0));
replace m_after1980=3 if m_after1980==20;
replace m_after1980=2 if m_after1980==10;
replace m_after1980=1 if m_after1980==0;
replace m_after1980=0 if m_after1980==-1;
label define m_after1980 
  0 "Before 1980" 
  1 "1980-1989" 
  2 "1990-1999"
  3 "2000+";
label values m_after1980 m_after1980 ;
char m_after1980[omit]3;

stsplit m_after35, after at (0,5,10) ( time =  35 + (M_BIRTH - M_B10)/12.0);
replace m_after35=-1 if m_after35==.; 
replace m_after35 = m_after35 + 1;


/*******************************************/
/* ESTIMATION  BIRTH 11                    */ 
/*******************************************/

xi: stpiece  i.m_after1980 i.m_after35, tp( 1, 3, 6, 9, 12 );

/* ********************************************************* */
/* ********************************************************* */
/* **                    BIRTH 12                         ** */
/* ********************************************************* */
/* ********************************************************* */


/*******************************************/
/* Settings and input file                 */
/*******************************************/

#delimit;
clear;
use m_mics_fertility.dta;
drop if M_B11 == .;

/*******************************************/
/* New Variables                           */
/*******************************************/

/* Record number */
generate m_recno = _n;

/* The studied event M_B12*/

generate m_birthevent = 0;
replace  m_birthevent = 1 if M_B12 != .;	

/* Observation time */

generate  m_duration = ( M_INTERV - M_B11 ) / 12.0;
replace   m_duration = ( M_B12 - M_B11 ) / 12.0 if m_birthevent==1;

/*******************************************/
/* EPISODE SPLITTING                       */ 
/*******************************************/

stset m_duration, failure(m_birthevent) id(m_recno);

/* splitting file in period episodes */

stsplit m_after1980, after at ( 0 10 20 ) ( time = 1980 - (1900 + M_B11 /12.0));
replace m_after1980=3 if m_after1980==20;
replace m_after1980=2 if m_after1980==10;
replace m_after1980=1 if m_after1980==0;
replace m_after1980=0 if m_after1980==-1;
label define m_after1980 
  0 "Before 1980" 
  1 "1980-1989" 
  2 "1990-1999"
  3 "2000+";
label values m_after1980 m_after1980 ;
char m_after1980[omit]3;

stsplit m_after35, after at (0,5,10) ( time =  35 + (M_BIRTH - M_B11)/12.0);
replace m_after35=-1 if m_after35==.; 
replace m_after35 = m_after35 + 1;


/*******************************************/
/* ESTIMATION  BIRTH 12                    */ 
/*******************************************/

xi: stpiece  i.m_after1980 i.m_after35, tp( 1, 3, 6, 9, 12 );


/* ********************************************************* */
/* ********************************************************* */
/* **                    BIRTH 13                         ** */
/* ********************************************************* */
/* ********************************************************* */


/*******************************************/
/* Settings and input file                 */
/*******************************************/

#delimit;
clear;
use m_mics_fertility.dta;
drop if M_B12 == .;

/*******************************************/
/* New Variables                           */
/*******************************************/

/* Record number */
generate m_recno = _n;

/* The studied event M_B13*/

generate m_birthevent = 0;
replace  m_birthevent = 1 if M_B13 != .;	

/* Observation time */

generate  m_duration = ( M_INTERV - M_B12 ) / 12.0;
replace   m_duration = ( M_B13 - M_B12 ) / 12.0 if m_birthevent==1;

/*******************************************/
/* EPISODE SPLITTING                       */ 
/*******************************************/

stset m_duration, failure(m_birthevent) id(m_recno);

/* splitting file in period episodes */

stsplit m_after1980, after at ( 0 10 20 ) ( time = 1980 - (1900 + M_B12 /12.0));
replace m_after1980=3 if m_after1980==20;
replace m_after1980=2 if m_after1980==10;
replace m_after1980=1 if m_after1980==0;
replace m_after1980=0 if m_after1980==-1;
label define m_after1980 
  0 "Before 1980" 
  1 "1980-1989" 
  2 "1990-1999"
  3 "2000+";
label values m_after1980 m_after1980 ;
char m_after1980[omit]3;

stsplit m_after35, after at (0,5,10) ( time =  35 + (M_BIRTH - M_B12)/12.0);
replace m_after35=-1 if m_after35==.; 
replace m_after35 = m_after35 + 1;


/*******************************************/
/* ESTIMATION BIRTH 13                     */ 
/*******************************************/

xi: stpiece  i.m_after35, tp( 1, 3, 6, 9, 12 );



/* ********************************************************* */
/* ********************************************************* */
/* **                    BIRTH 14                         ** */
/* ********************************************************* */
/* ********************************************************* */


/*******************************************/
/* Settings and input file                 */
/*******************************************/

#delimit;
clear;
use m_mics_fertility.dta;
drop if M_B13 == .;

/*******************************************/
/* New Variables                           */
/*******************************************/

/* Record number */
generate m_recno = _n;

/* The studied event M_B14*/

generate m_birthevent = 0;
replace  m_birthevent = 1 if M_B14 != .;	

/* Observation time */

generate  m_duration = ( M_INTERV - M_B13 ) / 12.0;
replace   m_duration = ( M_B14 - M_B13 ) / 12.0 if m_birthevent==1;

/*******************************************/
/* EPISODE SPLITTING                       */ 
/*******************************************/

stset m_duration, failure(m_birthevent) id(m_recno);

/* splitting file in period episodes */

stsplit m_after1980, after at ( 0 10 20 ) ( time = 1980 - (1900 + M_B13 /12.0));
replace m_after1980=3 if m_after1980==20;
replace m_after1980=2 if m_after1980==10;
replace m_after1980=1 if m_after1980==0;
replace m_after1980=0 if m_after1980==-1;
label define m_after1980 
  0 "Before 1980" 
  1 "1980-1989" 
  2 "1990-1999"
  3 "2000+";
label values m_after1980 m_after1980 ;
char m_after1980[omit]3;

stsplit m_after35, after at (0,5,10) ( time =  35 + (M_BIRTH - M_B13)/12.0);
replace m_after35=-1 if m_after35==.; 
replace m_after35 = m_after35 + 1;


/*******************************************/
/* ESTIMATION BIRTH 14                     */ 
/*******************************************/

xi: stpiece  , tp( 1, 3, 6, 9, 12 );


log close;
