/*
	ANALYSIS OF CHILD MORTALITY 
	DATA FROM MICS MAURETANIA
	MARTIN SPIELAUER, 2016

	Input file: m_mics_childmortality.dta
*/


/*
 -------------------------------
 Wrapper function stpiece
 -------------------------------
 the following adds the wrapper function stpiece which can be used to make code more efficient;
 without this function, time splits of the baseline duration have to be done manually;
 the fuction can be added to Stata, download at: http://fmwww.bc.edu/repec/bocode/s/stpiece.ado;
 it was developed by Jesper B. Sorensen Nov. 20 1999;

*/
 
clear all

program define stpiece
    version 6.0
    syntax [varlist(default=none numeric)] [if] [in] , [tp(numlist >=0) tv(varlist) PREsplit(integer -1) noPREserve *]
    if "`preserv'"=="" {
        preserve
    }
    if "`presplit'" == "-1" {
        if "`tp'"=="" {
            di in red "You must either declare data to be presplit or use tp()"
            exit 198
        }
        di in gr "Invoking stsplit..."
        qui stsplit tp, at(`tp') 
        di in gr "Creating time pieces..."
        qui tab tp, gen(tp)
        local i = _result(2)
        drop tp
    }
    else {
        local i = "`presplit'"
    }
    if "`tv'" ~= "" {
        di in gr "Creating interaction effects..."
        tokenize `tv'
        while "`1'" ~= "" {
            local stub = substr("`1'",1,4)
            local j=0
            while "`j'" < "`i'" {
                local j = `j'+1
                local x = "tp`stub'`j'"
                qui gen  `x'=`1'*tp`j'
            }
         mac shift
        }
    }

    streg tp* `varlist' `if' `in' , nocons d(e) `options'

end

/*******************************************/
/* Settings and file of birth records      */
/*******************************************/

clear
#delimit; 
capture log close
#delimit; 
set more off;
set linesize 255;
log using "C:\Users\pc\Desktop\usb_dynamiscmap\Log files\16_MICS_AnalysisChildMortality_cmap.smcl", replace smcl;
use "C:\Users\pc\Desktop\usb_dynamiscmap\Bases\MICS2015\m_mics_childmortality.dta";

/*******************************************/
/* Variables                               */
/*******************************************/

generate RecNo = _n;

/* Person died - this is the event studied */

generate ChildDied = 0;
replace  ChildDied = 1 if M_DEATH != .;

/* Observation time */

generate DUR = ( M_INTERV - M_BIRTH ) / 12.0;
replace  DUR = ( M_DEATH - M_BIRTH ) / 12.0 if ChildDied == 1;

/* Censor at age 5 and drop cases with death after age 5 */

replace ChildDied = 0 if DUR > 5;
replace DUR=5 if DUR>5;

/* Mothers age group at birth */

gen AgeGrMo = 2;
replace AgeGrMo = 1 if ( M_AGEMO / 12.0) < 17.0;
replace AgeGrMo = 0 if ( M_AGEMO / 12.0) < 15.0;
char AgeGrMo[omit]2;

/* Mother graduated from primary school */

gen MothNoPrim = 0; replace MothNoPrim = 1 if M_EDUCMO < 2; 

/*******************************************/
/* Episode splitting                       */
/*******************************************/

 
stset DUR, failure(ChildDied) id(RecNo);

/* splitting file in period episodes */

stsplit After1980, after at ( 0 10 20 30) ( time = 1980 - (1900 + M_BIRTH /12.0) );
replace After1980=4 if After1980==30;
replace After1980=3 if After1980==20;
replace After1980=2 if After1980==10;
replace After1980=1 if After1980==0;
replace After1980=0 if After1980==-1;
label define After1980 
  0 "Before 1980" 
  1 "1980-1989" 
  2 "1990-1999"
  3 "2000-2009"
  4 "2010+";
label values After1980 After1980 ;
char After1980[omit]4;


/*******************************************/
/* Estimation                              */
/*******************************************/

xi: stpiece i.After1980 i.AgeGrMo i.MothNoPrim i.M_MALE, tp( 1, 2, 3, 4 );

log close;

